abacusai.api_class.blob_input — AbacusAI documentation

# `abacusai.api_class.blob_input`

## Module Contents

### Classes

`Blob` | Binary large object data.
`BlobInput` | Binary large object data.

class abacusai.api_class.blob_input.Blob(contents, mime_type=None, filename=None, size=None)

  Bases: `abacusai.api_class.abstract.ApiClass`

  Binary large object data.

  Parameters:

    - filename (str) – The original filename of the blob.

    - contents (bytes) – The binary contents of the blob.

    - mime_type (str) – The mime type of the blob.

    - size (int) – The size of the blob in bytes.

  filename: str
  contents: bytes
  mime_type: str
  size: int
  classmethod from_local_file(file_path)
    Parameters:

      file_path (str)

    Return type:

      Blob

  classmethod from_contents(contents, filename=None, mime_type=None)
    Parameters:

      - contents (bytes)

      - filename (str)

      - mime_type (str)

    Return type:

      Blob

class abacusai.api_class.blob_input.BlobInput(filename=None, contents=None, mime_type=None, size=None)

  Bases: `Blob`

  Binary large object data. An alias for Blob, used to indicate that this is an input object.

  Parameters:

    - filename (str)

    - contents (bytes)

    - mime_type (str)

    - size (int)